==> ktorrent-4.0.5.tar.xz: ktorrent-4.0.5/plugins/webinterface/challengegenerator.h <==
/***************************************************************************
 *   Copyright (C) 2008 by Joris Guisson and Ivan Vasic                    *
 *   joris.guisson@gmail.com                                               *
 *   ivasic@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#ifndef KTCHALLENGEGENERATOR_H
#define KTCHALLENGEGENERATOR_H

#include <webcontentgenerator.h>

namespace kt
{

	/**
		Generates XML containg the challenge field for login pages
	*/
	class ChallengeGenerator : public WebContentGenerator
	{
	public:
		ChallengeGenerator(HttpServer* server);
		virtual ~ChallengeGenerator();

		virtual void get(HttpClientHandler* hdlr,const QHttpRequestHeader& hdr);
		virtual void post(HttpClientHandler* hdlr,const QHttpRequestHeader& hdr,const QByteArray& data);

	};

}

#endif

==> ktorrent-4.3.1.tar.xz: ktorrent-4.3.1/plugins/webinterface/challengegenerator.h <==
/***************************************************************************
 *   Copyright (C) 2008 by Joris Guisson and Ivan Vasic                    *
 *   joris.guisson@gmail.com                                               *
 *   ivasic@gmail.com                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/
#ifndef KTCHALLENGEGENERATOR_H
#define KTCHALLENGEGENERATOR_H

#include <webcontentgenerator.h>

namespace kt
{

	/**
		Generates XML containing the challenge field for login pages
	*/
	class ChallengeGenerator : public WebContentGenerator
	{
	public:
		ChallengeGenerator(HttpServer* server);
		virtual ~ChallengeGenerator();

		virtual void get(HttpClientHandler* hdlr,const QHttpRequestHeader& hdr);
		virtual void post(HttpClientHandler* hdlr,const QHttpRequestHeader& hdr,const QByteArray& data);

	};

}

#endif
